Module provider

Module provider 

Defines the BfsSettingsProvider trait and related types.

Enums

ChunkFilesBehavior
Defines the behavior of chunk files at the end of each iteration.
UpdateFilesBehavior
Defines the behavior of update files and update bit arrays at the end of each iteration.

Traits

BfsSettingsProvider
Provider for some additional settings for the BFS.