pub enum ChunkFilesBehavior {
Delete,
Keep,
}Expand description
Defines the behavior of chunk files at the end of each iteration.
Variants
Delete
Delete chunk files at the end of the iteration.
Keep
Move chunk files to a backup directory at the end of the iteration.