UpdateFilesBehavior

Enum UpdateFilesBehavior 

pub enum UpdateFilesBehavior {
    DontMerge,
    MergeAndDelete,
    MergeAndKeep,
}
Defines the behavior of update files and update bit arrays at the end of each iteration.

Variants



DontMerge

Don’t merge update files into a bit array at the end of the iteration.



MergeAndDelete

Merge update files into a bit array at the end of the iteration, and delete them after they have been used.



MergeAndKeep

Merge update files into a bit array at the end of the iteration, and move them to a backup directory after they have been used.