BfsBuilderError

Enum BfsBuilderError 

pub enum BfsBuilderError {
Show 21 variants ThreadsNotSet, ChunkSizeBytesNotSet, UpdateMemoryNotSet, NumUpdateBlocksNotSet, CapacityCheckFrequencyNotSet, InitialStatesNotSet, StateSizeNotSet, RootDirectoriesNotSet, InitialMemoryLimitNotSet, AvailableDiskSpaceLimitNotSet, UpdateArrayThresholdNotSet, UseLockedIoNotSet, SyncFilesystemNotSet, ComputeChecksumsNotSet, UseCompressionNotSet, ExpanderNotSet, CallbackNotSet, SettingsProviderNotSet, ChunkSizeTooLarge { chunk_size_bytes: usize, }, ChunksNotSameSize { state_size: u64, chunk_size_bytes: usize, }, NotEnoughUpdateBlocks { num_update_blocks: usize, threads: usize, num_chunks: usize, },
}
Error type for BfsBuilder.

Variants



ThreadsNotSet

The threads parameter was not set.



ChunkSizeBytesNotSet

The chunk_size_bytes parameter was not set.



UpdateMemoryNotSet

The update_memory parameter was not set.



NumUpdateBlocksNotSet

The num_update_blocks parameter was not set.



CapacityCheckFrequencyNotSet

The capacity_check_frequency parameter was not set.



InitialStatesNotSet

The initial_states parameter was not set.



StateSizeNotSet

The state_size parameter was not set.



RootDirectoriesNotSet

The root_directories parameter was not set.



InitialMemoryLimitNotSet

The initial_memory_limit parameter was not set.



AvailableDiskSpaceLimitNotSet

The available_disk_space_limit parameter was not set.



UpdateArrayThresholdNotSet

The update_array_threshold parameter was not set.



UseLockedIoNotSet

The use_locked_io parameter was not set.



SyncFilesystemNotSet

The sync_filesystem parameter was not set.



ComputeChecksumsNotSet

The compute_checksums parameter was not set.



UseCompressionNotSet

The use_compression parameter was not set.



ExpanderNotSet

The expander parameter was not set.



CallbackNotSet

The callback parameter was not set.



SettingsProviderNotSet

The settings_provider parameter was not set.



ChunkSizeTooLarge

The chunk_size_bytes parameter was too large.

Fields

chunk_size_bytes: usize

The provided chunk size in bytes.



ChunksNotSameSize

Not all chunks of the bit array are the same size.

Fields

state_size: u64

The provided state size.

chunk_size_bytes: usize

The provided chunk size in bytes.



NotEnoughUpdateBlocks

Not enough update blocks for the given number of threads and chunks.

Fields

num_update_blocks: usize

The provided number of update blocks.

threads: usize

The provided number of threads.

num_chunks: usize

The number of chunks, calculated from the state size and chunk size.