Defines the BfsSettingsProvider trait and related types.
Enums
- Chunk
Files Behavior - Defines the behavior of chunk files at the end of each iteration.
- Update
Files Behavior - Defines the behavior of update files and update bit arrays at the end of each iteration.
Traits
- BfsSettings
Provider - Provider for some additional settings for the BFS.