BfsSettingsProvider

Trait BfsSettingsProvider 

pub trait BfsSettingsProvider {
    // Required methods
    fn chunk_root_idx(&self, chunk_idx: usize) -> usize;
    fn update_files_behavior(&self, depth: usize) -> UpdateFilesBehavior;
    fn chunk_files_behavior(&self, depth: usize) -> ChunkFilesBehavior;
}
Provider for some additional settings for the BFS.

Required Methods

fn chunk_root_idx(&self, chunk_idx: usize) -> usize

Returns an index into BfsBuilder::root_directories that defines which hard drive the given chunk should be stored on.

fn update_files_behavior(&self, depth: usize) -> UpdateFilesBehavior

Returns the behavior of update files at the end of the depth depth iteration.

fn chunk_files_behavior(&self, depth: usize) -> ChunkFilesBehavior

Returns the behavior of chunk files at the end of the depth depth iteration.

Implementors